@@ -148,7 +148,7 @@ def _parse_sklearn_classifier(scope, model, inputs, zipmap=True):
             SequenceType(DictionaryType(label_type, FloatTensorType())))
     else:
         output_probability = scope.declare_local_variable(
-            'probabilities', FloatTensorType())
+            'probabilities', FloatTensorType(shape=[None, len(classes)]))
     this_operator.outputs.append(output_label)
     this_operator.outputs.append(output_probability)
     return this_operator.outputs
