@@ -32,4 +32,6 @@ from . import string_indexer
 from . import linear_classifier
 from . import onehot_encoder
 from . import vector_assembler
-
+from . import k_means
+from . import count_vectorizer
+from . import mlp_classifier
