@@ -4,6 +4,7 @@ import pickle
 import os
 import warnings
 import numpy
+import packaging.version as pv
 from onnx.defs import onnx_opset_version
 from onnxconverter_common.onnx_ex import DEFAULT_OPSET_NUMBER
 from ..convert.common.data_types import FloatTensorType
@@ -40,7 +41,7 @@ def dump_data_and_model(data, model, onnx=None, basename="model", folder=None,
     :param allow_failure: None to raise an exception if comparison fails
         for the backends, otherwise a string which is then evaluated to check
         whether or not the test can fail, example:
-        ``"StrictVersion(onnx.__version__) < StrictVersion('1.3.0')"``
+        ``"pv.Version(onnx.__version__) < pv.Version('1.3.0')"``
     :param verbose: prints more information when it fails
     :return: the created files
 
@@ -112,7 +113,18 @@ def dump_data_and_model(data, model, onnx=None, basename="model", folder=None,
                 prediction = [model.predict(datax)]
         elif hasattr(model, "predict_proba"):
             # Classifier
-            prediction = [model.predict(data), model.predict_proba(data)]
+            if hasattr(model, 'get_params'):
+                params = model.get_params()
+                if 'objective' in params:
+                    objective = params['objective']
+                    if objective == "multi:softmax":
+                        prediction = [model.predict(data)]
+                    else:
+                        prediction = [model.predict(data), model.predict_proba(data)]
+                else:
+                    prediction = [model.predict(data), model.predict_proba(data)]
+            else:
+                prediction = [model.predict(data), model.predict_proba(data)]
         elif hasattr(model, "predict_with_probabilities"):
             # Classifier that returns all in one go
             prediction = model.predict_with_probabilities(data)
@@ -243,7 +255,7 @@ def dump_one_class_classification(model, suffix="", folder=None, allow_failure=N
     :param allow_failure: None to raise an exception if comparison fails
         for the backends, otherwise a string which is then evaluated to check
         whether or not the test can fail, example:
-        ``"StrictVersion(onnx.__version__) < StrictVersion('1.3.0')"``
+        ``"pv.Version(onnx.__version__) < pv.Version('1.3.0')"``
     :return: output of :func:`dump_data_and_model`
 
     Every created filename will follow the pattern:
@@ -269,7 +281,7 @@ def dump_binary_classification(model, suffix="", folder=None, allow_failure=None
     :param allow_failure: None to raise an exception if comparison fails
         for the backends, otherwise a string which is then evaluated to check
         whether or not the test can fail, example:
-        ``"StrictVersion(onnx.__version__) < StrictVersion('1.3.0')"``
+        ``"pv.Version(onnx.__version__) < pv.Version('1.3.0')"``
     :param verbose: prints more information when it fails
     :return: output of :func:`dump_data_and_model`
 
@@ -296,7 +308,7 @@ def dump_multiple_classification(model, suffix="", folder=None, allow_failure=No
     :param allow_failure: None to raise an exception if comparison fails
         for the backends, otherwise a string which is then evaluated to check
         whether or not the test can fail, example:
-        ``"StrictVersion(onnx.__version__) < StrictVersion('1.3.0')"``
+        ``"pv.Version(onnx.__version__) < pv.Version('1.3.0')"``
     :return: output of :func:`dump_data_and_model`
 
     Every created filename will follow the pattern:
@@ -322,7 +334,7 @@ def dump_multiple_regression(model, suffix="", folder=None, allow_failure=None):
     :param allow_failure: None to raise an exception if comparison fails
         for the backends, otherwise a string which is then evaluated to check
         whether or not the test can fail, example:
-        ``"StrictVersion(onnx.__version__) < StrictVersion('1.3.0')"``
+        ``"pv.Version(onnx.__version__) < pv.Version('1.3.0')"``
     :return: output of :func:`dump_data_and_model`
 
     Every created filename will follow the pattern:
@@ -349,7 +361,7 @@ def dump_single_regression(model, suffix="", folder=None, allow_failure=None):
     :param allow_failure: None to raise an exception if comparison fails
         for the backends, otherwise a string which is then evaluated to check
         whether or not the test can fail, example:
-        ``"StrictVersion(onnx.__version__) < StrictVersion('1.3.0')"``
+        ``"pv.Version(onnx.__version__) < pv.Version('1.3.0')"``
     :return: output of :func:`dump_data_and_model`
 
     Every created filename will follow the pattern:
