@@ -3,7 +3,7 @@
 import sys
 import inspect
 import unittest
-from distutils.version import StrictVersion
+import packaging.version as pv
 import onnx
 import pandas
 import numpy
@@ -19,17 +19,17 @@ from tests.sparkml import SparkMlTestCase
 from pyspark.ml.feature import StringIndexer, VectorIndexer
 
 
-TARGET_OPSET = min(DEFAULT_OPSET_NUMBER, onnx_opset_version())
+TARGET_OPSET = min(15, min(DEFAULT_OPSET_NUMBER, onnx_opset_version()))
 
 
 class TestSparkmDecisionTreeClassifier(SparkMlTestCase):
 
-    @unittest.skipIf(True, reason="Mismatched input dimensions.")
+    # @unittest.skipIf(True, reason="Mismatched input dimensions.")
     @unittest.skipIf(sys.platform == 'win32',
                      reason="UnsatisfiedLinkError")
     @unittest.skipIf(sys.version_info < (3, 8),
                      reason="pickle fails on python 3.7")
-    @unittest.skipIf(StrictVersion(onnx.__version__) <= StrictVersion('1.3'), 'Need Greater Opset 9')
+    @unittest.skipIf(pv.Version(onnx.__version__) <= pv.Version('1.3'), 'Need Greater Opset 9')
     def test_tree_pipeline(self):
         import os
         this_script_dir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
@@ -72,7 +72,7 @@ class TestSparkmDecisionTreeClassifier(SparkMlTestCase):
         output, output_shapes = run_onnx_model(['indexedLabel', 'prediction', 'probability'], data_np, onnx_model_path)
         compare_results(expected, output, decimal=5)
 
-    @unittest.skipIf(True, reason="Mismatched input dimensions.")
+    # @unittest.skipIf(True, reason="Mismatched input dimensions.")
     @unittest.skipIf(sys.platform == 'win32',
                      reason="UnsatisfiedLinkError")
     @unittest.skipIf(sys.version_info < (3, 8),
@@ -80,7 +80,7 @@ class TestSparkmDecisionTreeClassifier(SparkMlTestCase):
     def test_tree_one_class_classification(self):
         features = [[0., 1.], [1., 1.], [2., 0.]]
         features = numpy.array(features, dtype=numpy.float32)
-        labels = [1, 1, 1]
+        labels = [1, 1, 0]
         dd = [(labels[i], Vectors.dense(features[i])) for i in range(len(labels))]
         data = self.spark.createDataFrame(self.spark.sparkContext.parallelize(dd), schema=["label", "features"])
         dt = DecisionTreeClassifier(labelCol="label", featuresCol="features")
